V1.0.0(The main role)(Beta)
This package depends on socket,threading,PySimpleGUI,requests,ctypes,easygui
This package can help you perform DOS attack testing faster
V1.0.1(Beta)
Fixed some known issues
V1.0.2(Beta)
Use an integration approach
V1.0.3(Beta)
Fix annotation issues
When confirming the network connection situation,using a random timeout 
DosKill will rely on the random,but this is not mandatory
We use the try method to ensure that some Python versions can still use DosKill normally
For confirming network connectivity,we use PyPi.org
Fix the file encapsulation problem, you can directly call the dosKill library DOS.py file
After August 18,2022,the maintenance and update of the library will be slower,but we will not terminate the maintenance and update
V1.0.4
Fixed some known issues